@@ -1,5 +1,5 @@
 """
-Module for handling Task data supplied in a CSV file
+Module for handling Task data supplied in CSV files.
 """
 
 import csv
@@ -168,7 +168,7 @@ def perform_csv_task_expansion(wr_data: Dict, csv_files: List[str]) -> Dict:
     if len(wr_data[TASK_GROUPS]) > len(csv_files):
         print_log(
             f"Note: Number of Task Groups ({len(wr_data[TASK_GROUPS])}) "
-            f"in Work Requirement is greater than number of CSV files "
+            "in Work Requirement is greater than number of CSV files "
             f"({len(csv_files)})"
         )
 
@@ -195,7 +195,7 @@ def perform_csv_task_expansion(wr_data: Dict, csv_files: List[str]) -> Dict:
 
         if not substitions_present(csv_data.var_names, str(task_prototype)):
             print_log(
-                f"Warning: No CSV substitutions to apply to Task Group "
+                "Warning: No CSV substitutions to apply to Task Group "
                 f"{index + 1}; not expanding Task list"
             )
             continue
@@ -336,7 +336,6 @@ def csv_expand_toml_tasks(config_wr: ConfigWorkRequirement, csv_file: str) -> Di
     # Populate properties that can be set at Task level only
     for config_value, config_name in [
         (config_wr.args, ARGS),
-        (config_wr.bash_script, BASH_SCRIPT),
         (config_wr.capture_taskoutput, CAPTURE_TASKOUTPUT),
         (config_wr.docker_env, DOCKER_ENV),
         (config_wr.docker_password, DOCKER_PASSWORD),
